::
:: This script retrieves the most recent error or warning posted to the
:: Media Center Event Log by EPG123 and e-mails it to
:: a specified e-mail address.  It should be placed in the EPG123 folder.
::
:: EPG123 Warnings are event ID 47825 and Errors are event ID 57005
::
@echo off
::
:: Set configuration parameters
::
:: Identify EPG123 directory. Normally C:\epg123
::
set epg123loc=C:\epg123
::
:: Set variables to allow e-mail client to logon and send an e-mail.
::
:: For comcast e-mail these might look like:
::   set mailserver=smtp.comcast.net
::   set port=587
::   set protocol=normal
::   set username=YourEmailUserName
::   set mailpw=YourEmailPassword
::   set sender=YourEmailLogonID@comcast.net
::   set recipient=DesiredRecipient@comcast.net
::
:: For gmail e-mail these might look like:
::   set mailserver=smtp.gmail.com
::   set port=587
::   set protocol=ssl
::   set username=YourEmailUserName
::   set mailpw=YourEmailPassword
::   set sender=YourEmailLogonID@gmail.com
::   set recipient=DesiredRecipient@gmail.com
:: 
:: to send a text message many wireless providers have e-mail gateways
:: e.g. to send a text message to a Verizon account:
::   set recipient=CellphoneNumber@vtext.com
:: 
set mailserver=
set port=
set protocol=
set username=
set mailpw=
set sender=
set recipient=s
::
:: set message type to send
::    brief - short message suitable for texting
::    full  - long message with full error text/log info
::
set msgtype=full
::
:: set to on for debug mode
::
set debugmode=off
::
if "%debugmode%"=="on" echo event triggered at %date% %time%> %epg123loc%\errevt.log
::
:: See if we are sending warning or error notification
::
if "%~1"=="warning" (
set dowarning=yes
if "%debugmode%"=="on" echo sending warning >> %epg123loc%\errevt.log
) else (
set dowarning=no
if "%debugmode%"=="on" echo sending error >> %epg123loc%\errevt.log
)
::
if "%msgtype%"=="full" goto LONGMSG
::
:: Create short text message
::
if "%dowarning%"=="yes" (
set "subject=EPG123 Guide Update Warning(s)"
set body=EPG123 Guide update Warning(s), Check Media Center Event log and EPG123 trace log for details
) else (
set subject=EPG123 Guide Update Error
set body=EPG123 Guide update failed, Check Media Center Event log and EPG123 trace log for details
)
::
:: send brief failure message
::
if "%debugmode%"=="on" echo sending e-mail >> %epg123loc%\errevt.log 
%epg123loc%\senditquiet -s %mailserver% ^
  -port %port% -u %username% -p %mailpw% -f %sender% ^
  -t %recipient% -protocol %protocol% ^
  -subject "subject" ^
  -body "%body%"
goto END
::
:: create detailed error e-mail message
::
:LONGMSG
::
:: Clean up tmp file
::
del %epg123loc%\ErrorEvent.txt 2>nul
::
::
:: Get most recent EPG123 error or warning event from Media Center event log
::
if "%dowarning%"=="yes" (
set level=3
) else (
set level=2
)
if "%debugmode%"=="on" echo getting event from event log >> %epg123loc%\errevt.log
wevtutil qe "Media Center" "/q:*[System[Provider[@Name='EPG123']and(Level=%level%)]]" /f:text ^
  /rd:True /c:1 > %epg123loc%\ErrorEvent.txt
::
:: Wait for a few minutes for the update to finish in case EPG123 threw a warning early in the update.
::
ping 127.0.0.1 -n 240 > nul
::
:: Get the log messages from the most recent run from EPG123's trace.log
::
if "%debugmode%"=="on" echo getting log messages from trace.log >> %epg123loc%\errevt.log
echo Most recent Update attempt from EPG123 trace log: >> %epg123loc%\ErrorEvent.txt
echo.>> %epg123loc%\ErrorEvent.txt
del %epg123loc%\tmp.txt 2>nul
echo 1:Beginning epg123 update > %epg123loc%\tmp.txt
findstr /n /c:"Beginning epg123 update" %epg123loc%\trace.log >> %epg123loc%\tmp.txt
for /f "tokens=1 delims=:" %%i in (%epg123loc%\tmp.txt) do set lnum=%%i
set /a lnum=lnum-1
more +%lnum% %epg123loc%\trace.log >> %epg123loc%\ErrorEvent.txt
if "%dowarning%"=="yes" (
set "subject=EPG123 Guide Update Warning(s)"
set body=EPG123 Warning event details attached:
) else (
set subject=EPG123 Guide Update Error
set body=EPG123 Error event details attached:
)
::
:: mail warning to somebody
::
if "%debugmode%"=="on" ping 127.0.0.1 -n 30 > nul
if "%debugmode%"=="on" echo sending e-mail >> %epg123loc%\errevt.log 
%epg123loc%\senditquiet -s %mailserver% ^
  -port %port% -u %username% -p %mailpw% -f %sender% ^
  -t %recipient% -protocol %protocol% ^
  -subject "%subject%" ^
  -body "%body%" ^
  -files "%epg123loc%\ErrorEvent.txt"
:END
if errorlevel 0 (
if "%debugmode%"=="on" echo e-mail sent to %recipient% >> %epg123loc%\errevt.log
) else (
if "%debugmode%"=="on" echo e-mail failed >> %epg123loc%\errevt.log 
)
